Learn R Programming

clustcurv (version 3.0.1)

summary.clustcurves: Summarizing fits of kclustcurves class produced by survclustcurves and regclustcurves

Description

Takes a clustcurves object and produces various useful summaries from it.

Usage

# S3 method for clustcurves
summary(object, ...)

Value

summary.clustcurves computes and returns a list of summary information for a clustcurves object.

levels

Levels of the factor.

cluster

A vector containing the assignment of each factor's level to its group.

table

A data.frame containing the results from the hypothesis test.

Arguments

object

a clustcurves object as producted by survclustcurves and regclustcurves

...

additional arguments.

Author

Nora M. Villanueva and Marta Sestelo.

Details

print.clustcurves tries to be smart about summary.clustcurves.

Examples

Run this code
library(clustcurv)
library(survival)
data(veteran)

# Survival framework
ressurv <- survclustcurves(time = veteran$time, status = veteran$status,
x = veteran$celltype, algorithm = 'kmeans', nboot = 2)

summary(ressurv)


# Regression framework
resreg <- regclustcurves(y = barnacle5$DW, x = barnacle5$RC, z = barnacle5$F,
algorithm = 'kmeans', nboot = 2)

summary(resreg)



Run the code above in your browser using DataLab