Learn R Programming

clustcurv (version 3.0.1)

summary.kcurves: Summarizing fits of kcurves class produced by ksurvcurves and kregcurves

Description

Takes a kcurves object and produces various useful summaries from it.

Usage

# S3 method for kcurves
summary(object, ...)

Value

summary.kcurves computes and returns a list of summary information for a kcurves object.

levels

Levels of the factor.

cluster

A vector containing the assignment of each factor's level to its group.

Arguments

object

a kcurves object as producted by ksurvcurves and kregcurves

...

additional arguments.

Author

Nora M. Villanueva and Marta Sestelo.

Details

print.kcurves tries to be smart about summary.kcurves.

Examples

Run this code
library(clustcurv)
library(survival)
data(veteran)

# Survival: 2 groups k-means
s2 <- ksurvcurves(time = veteran$time, status = veteran$status,
x = veteran$celltype, k = 2, algorithm = "kmeans")

summary(s2)


# Regression: 2 groups k-means
r2 <- kregcurves(y = barnacle5$DW, x = barnacle5$RC,
z = barnacle5$F, k = 2, algorithm = "kmeans")

summary(r2)



Run the code above in your browser using DataLab